﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Mvc;
using Sample.Models;
using Syncfusion.DocIO;
using Syncfusion.DocIO.DLS;
using Syncfusion.DocIORenderer;
using Syncfusion.Pdf;

namespace Sample.Controllers
{
    public class HomeController : Controller
    {
        private readonly IHostingEnvironment _hostingEnvironment;
        public HomeController(IHostingEnvironment hostingEnvironment)
        {
            _hostingEnvironment = hostingEnvironment;
        }

        public IActionResult Index()
        {
            return View();
        }

        [HttpPost]

        public IActionResult ConvertToPDF()
        {
            string basePath = _hostingEnvironment.WebRootPath;

            FileStream fileStreamInput = new FileStream(basePath + @"/Sample.Docx", FileMode.Open, FileAccess.Read);
            
            //Loads an existing Word document
            WordDocument wordDocument = new WordDocument(fileStreamInput, FormatType.Automatic);

            //Instantiates DocIORenderer instance for Word to PDF conversion
            DocIORenderer renderer = new DocIORenderer();

            renderer.Settings.EmbedCompleteFonts = true;

            MemoryStream wordStream = new MemoryStream();

            wordDocument.Save(wordStream,FormatType.Docx);

            wordStream.Position = 0;

            wordDocument.Close();

            WordDocument newWordDocument = new WordDocument(wordStream,FormatType.Docx);

            //Converts Word document into PDF document
            PdfDocument pdfDocument = renderer.ConvertToPDF(newWordDocument);

            MemoryStream pdfStream = new MemoryStream();

            //Save the converted PDF document to Memory stream.
            pdfDocument.Save(pdfStream);
            pdfStream.Position = 0;

            newWordDocument.Close();

            //Close the PDF document.
            pdfDocument.Close(true);

            //Releases the resources occupied by DocIORenderer instance
            renderer.Dispose();

            //Initialize the file stream to download the converted PDF.
            FileStreamResult fileStreamResult = new FileStreamResult(pdfStream, "application/pdf");
            //Set the file name.
            fileStreamResult.FileDownloadName = "Sample.pdf";

            return fileStreamResult;
        }



        public IActionResult About()
        {
            ViewData["Message"] = "Your application description page.";

            return View();
        }

        public IActionResult Contact()
        {
            ViewData["Message"] = "Your contact page.";

            return View();
        }

        public IActionResult Error()
        {
            return View(new ErrorViewModel { RequestId = Activity.Current?.Id ?? HttpContext.TraceIdentifier });
        }
    }
}
